/***************************************************************************
 *   Copyright (C) 2006 by Ken Werner                                      *
 *   ken.werner@web.de                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef IBMACPITHERMALSRC_H
#define IBMACPITHERMALSRC_H
#include "source.h"
#include <map>

/**
 * IBMACPIThermalSrc reads temperature values from /proc/acpi/ibm/thermal
 * which is provided by the ibm-acpi kernel module.
 */
class IBMACPIThermalSrc : public Source {
public:
	/**
	 * Creates a new Source from the given File and index
	 */
	IBMACPIThermalSrc(const QFile& inSourceFile, unsigned int inIndex);
	virtual ~IBMACPIThermalSrc();
	
	/**
	 * Returns the value of this source
	 */
	virtual QString getValue();

private:
	/**
	 * Returns the name (such as CPU, GPU, ...) of the sensor according to a given index
	 */
	static QString index2Name(unsigned int inIndex);

	/**
	 * the index of the source in /proc/acpi/ibm/thermal
	 */
	unsigned int mIndex;
};
#endif //IBMACPITHERMALSRC_H
