/***************************************************************************
 *   Copyright (C) 2006 by Ken Werner                                      *
 *   ken.werner@web.de                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "source.h"
#include <math.h>

Source::Source(const QFile& inSourceFile):
		mSourceFile(inSourceFile.name()),
	mName("unnamed source"),
	mDescription("This source obtains its data from: " + inSourceFile.name()){
}

Source::~Source(){
}

QString Source::getName(){
	return mName;
}

QString Source::getDescription(){
	return mDescription;
}

QString Source::getPath(){
	return mSourceFile.name();
}

QString Source::KHzinHumanReadable( uint value ){
	if( value >= 1000000 )
		return QString::number( round(value/1000000.0, 1) ) + " GHz";
	else if( value >= 1000 )
		return QString::number( round(value/1000.0, 0) ) + " MHz";
	else
		return QString::number( value ) + " KHz";
}

double Source::round(double inValue, int inDigits){
    return floor(inValue * pow( 10, inDigits) + 0.5) * pow(10, -inDigits);
}

int Source::celsiusToFahrenheit(int inCelsius){
	return qRound(1.8 * inCelsius + 32);
}
