/***************************************************************************
 *   Copyright (C) 2006 by Ken Werner                                      *
 *   ken.werner@web.de                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef SOURCE_H
#define SOURCE_H
#include <qstring.h>
#include <qfile.h>

/**
 * Abstract Source
 * @author Ken Werner
 */
class Source {
public:
	/**
	 * Creates a new Source from the given File
	 */
	Source(const QFile& inSourceFile);
	virtual ~Source();
	
	/**
	 * Returns the value of this source
	 */
	virtual QString getValue() = 0;

	/**
	 * Returns the Name of this source
	 */
	virtual QString getName();

	/**
	 * Returns the Description of this source
	 */
	virtual QString getDescription();

	/**
	 * Returns path this source
	 */
	virtual QString getPath();

	/**
	 * Translates a given frequency in KHz into a human readable string
	 */
	virtual QString KHzinHumanReadable( uint value );

	/**
	 * Translates degree Celsius into degree Fahrenheit
	 */
	int celsiusToFahrenheit(int inCelsius);

	/**
	 * Returns inValue rounded to inDigits
	 */
	double round(double inValue, int inDigits=0);

protected:
	 QFile mSourceFile;
	 QString mName;
	 QString mDescription;
};
#endif //SOURCE_H
